@@ -1,12 +1,12 @@
 package Ubic;
 {
-  $Ubic::VERSION = '1.37_01';
+  $Ubic::VERSION = '1.37_02';
 }
 
 use strict;
 use warnings;
 
-# ABSTRACT: flexible perl-based service manager
+# ABSTRACT: polymorphic service manager
 
 
 use POSIX qw();
@@ -70,7 +70,6 @@ sub new {
     $self->{lock_dir} = "$self->{data_dir}/lock";
     $self->{tmp_dir} = "$self->{data_dir}/tmp";
 
-    $self->{root} = Ubic::Multiservice::Dir->new($self->{service_dir});
     $self->{service_cache} = {};
     return bless $self => $class;
 }
@@ -185,7 +184,7 @@ sub is_enabled($$) {
     my $self = _obj(shift);
     my ($name) = validate_pos(@_, $validate_service);
 
-    die "Service '$name' not found" unless $self->{root}->has_service($name);
+    die "Service '$name' not found" unless $self->root_service->has_service($name);
     return unless -e $self->status_file($name);
 
     my $status_obj = $self->status_obj_ro($name);
@@ -243,7 +242,7 @@ sub service($$) {
     unless ($self->{service_cache}{$name}) {
         # Service construction is a memory-leaking operation (because of package name randomization in Ubic::Multiservice::Dir),
         # so we need to cache each service which we create.
-        $self->{service_cache}{$name} = $self->{root}->service($name);
+        $self->{service_cache}{$name} = $self->root_service->service($name);
     }
     return $self->{service_cache}{$name};
 }
@@ -253,21 +252,24 @@ sub has_service($$) {
     my ($name) = validate_pos(@_, $validate_service);
     # TODO - it would be safer to do this check without actual service construction
     # but it would require cron-based script which maintains list of all services
-    return $self->{root}->has_service($name);
+    return $self->root_service->has_service($name);
 }
 
 sub services($) {
     my $self = _obj(shift);
-    return $self->{root}->services();
+    return $self->root_service->services();
 }
 
 sub service_names($) {
     my $self = _obj(shift);
-    return $self->{root}->service_names();
+    return $self->root_service->service_names();
 }
 
 sub root_service($) {
     my $self = _obj(shift);
+    unless (defined $self->{root}) {
+        $self->{root} = Ubic::Multiservice::Dir->new($self->{service_dir}, { protected => 1 });
+    }
     return $self->{root};
 }
 
@@ -375,7 +377,7 @@ sub set_service_dir($$) {
     Ubic::Settings->service_dir($dir);
     if ($SINGLETON) {
         $SINGLETON->{service_dir} = $dir;
-        $SINGLETON->{root} = Ubic::Multiservice::Dir->new($dir);
+        undef $SINGLETON->{root}; # force lazy regeneration
     }
 }
 
@@ -500,11 +502,11 @@ __END__
 
 =head1 NAME
 
-Ubic - flexible perl-based service manager
+Ubic - polymorphic service manager
 
 =head1 VERSION
 
-version 1.37_01
+version 1.37_02
 
 =head1 SYNOPSIS
 
@@ -522,7 +524,7 @@ All of its methods can be invoked as class methods or object methods.
 
 =head1 INTRODUCTION
 
-Ubic is a flexible perl-based service manager.
+Ubic is a polymorphic service manager.
 
 This module is a perl frontend to ubic services.
 
@@ -703,7 +705,7 @@ Set ubic services dir.
 
 =head1 INTERNAL METHODS
 
-You shouldn't call these from code which doesn't belong to core Ubic distribution
+You shouldn't call these from a code which doesn't belong to core Ubic distribution.
 
 These methods can be changed or removed without further notice.
 
